@@ -4,6 +4,7 @@ Core functions handling connection and objects base
 import os
 import sys
 import json
+from distutils.version import StrictVersion
 from time import time as current_time
 import requests
 from pymiere.exe_utils import is_premiere_running
@@ -21,7 +22,7 @@ def check_premiere_is_alive(crash=True):
     :param crash: (bool) what to do if premiere is not connected
     :return: (bool) is premiere ready to receive instruction from python
     """
-    # search in globals the last time premiere was checked and if we need to chack again
+    # search in globals the last time premiere was checked and if we need to check it again
     global last_alive_check_time
     if "last_alive_check_time" in globals() and current_time() - last_alive_check_time < ALIVE_TIMEOUT:
         return True
@@ -52,6 +53,18 @@ def check_premiere_is_alive(crash=True):
     return True
 
 
+def get_premiere_version():
+    """
+    Query or get from cache the version of the currently running Premiere pro
+
+    :return: (StrictVersion) version object of current premiere pro
+    """
+    global premiere_pro_version
+    if "premiere_pro_version" not in globals():
+        premiere_pro_version = StrictVersion(eval_script("app.version;"))
+    return premiere_pro_version
+
+
 def eval_script(code=None, filepath=None, decode_json=True):
     """
     Send some ExtendScript code to premiere and wait for the returning value
@@ -74,9 +87,8 @@ def eval_script(code=None, filepath=None, decode_json=True):
         if not os.path.splitext(filepath)[-1] != "jsx":
             print("Passing a file '{}' that's not a .jsx to premiere, that's strange...".format(filepath))
 
-        # using encoding 'utf-8-sig' to work with file saved with Adobe ExtendScript Toolkit
-        with open(filepath, encoding='utf-8-sig') as f:
-            code = f.read()
+        with open(filepath, "rb") as f:
+            code = f.read().decode("UTF-8")
 
     # escape backslash for javascript
     code = code.replace("\\", "\\\\")
@@ -196,6 +208,28 @@ class PymiereBaseObject(object):
         if not isinstance(obj, cls):
             raise ValueError("{} shoud be of type {} but got '{}' (type {})".format(name, cls, obj, type(obj)))
 
+    @staticmethod
+    def _check_version(minimum_version, name, alternative_msg=None):
+        """
+        Check to use in subclass when creating a new property or method only available from a specific premiere
+        version to check and raise if it is not available because we are using an older premiere version
+
+        :param minimum_version: (str or StrictVersion) minimum version requirement to use this property/method
+        :param name: (str) name of the method/property
+        :param alternative_msg: (None or str) if given provide an alternative solution in the error message to achieve
+        the same behaviour with different code
+        """
+        current_version = get_premiere_version()
+        if not isinstance(minimum_version, StrictVersion):
+            minimum_version = StrictVersion(minimum_version)
+        if current_version >= minimum_version:
+            return
+        message = "'{}' is only available from Premiere Pro v{} and you are using v{}.".format(
+            name, minimum_version, current_version)
+        if alternative_msg:
+            message += "\nAlternative solution : {}".format(alternative_msg)
+        raise NameError(message)
+
 
 class PymiereBaseCollection(PymiereBaseObject):
     def __init__(self, pymiere_id, len_property):
@@ -379,6 +413,9 @@ def _format_object_to_es(obj):
         return "$._pymiere['{}']".format(obj._pymiere_id)
     elif isinstance(obj, list):
         return "$._pymiere['{}']".format(Array.from_python_list(obj)._pymiere_id)
+    elif isinstance(obj, dict):
+        key_value_pair = ["{}: {}".format(_format_object_to_es(k), _format_object_to_es(v)) for k, v in obj.items()]
+        return "{" + ",".join(key_value_pair) + "}"
     else:
         return str(obj)
 
@@ -402,6 +439,10 @@ def _format_object_to_py(obj):
             return available_subclasses["Dollar"](pymiere_id=obj.get("pymiereId"))
         else:
             return PymiereGenericObject(pymiere_id=obj["pymiereId"])
+    if isinstance(obj, dict) and obj.get("pymiere_id"):
+        # no idea how we can get to this situation but it happen so let's convert to an object wa can use
+        return PymiereGenericObject(pymiere_id=obj["pymiere_id"])
+
     return obj
 
 
